@@ -37,12 +37,13 @@
 
 namespace apvlv
 {
-  ApvlvCore::ApvlvCore (ApvlvView *view)
+  class ApvlvView;
+  extern ApvlvView *gView;
+
+  ApvlvCore::ApvlvCore ()
   {
     mInuse = true;
 
-    mView = view;
-
     mReady = false;
 
     mProCmd = 0;
@@ -89,7 +90,7 @@ namespace apvlv
   {
     mInuse = use;
 
-    if (mInuse == false && mView->hasloaded (filename (), type ()) == NULL)
+    if (mInuse == false && gView->hasloaded (filename (), type ()) == false)
       {
 	debug ("core :%p is not needed, delete it\n", this);
 	delete this;
@@ -213,7 +214,7 @@ namespace apvlv
       }
     else
       {
-	//debug ("fatal a timer error, try again!");
+	debug ("fatal a timer error, try again!");
 	return FALSE;
       }
   }
@@ -237,9 +238,9 @@ namespace apvlv
       }
     else
       {
-	if (mAutoScrollPage)
+	if (gParams->valueb ("autoscrollpage"))
 	  {
-	    if (mContinuous)
+	    if (gParams->valueb ("continuous"))
 	      {
 		showpage (mPagenum - 1,
 			  ((gtk_adjustment_get_upper(mVaj) / 2) - mVrate * times) / (sub -
@@ -274,9 +275,9 @@ namespace apvlv
       }
     else
       {
-	if (mAutoScrollPage)
+	if (gParams->valueb ("autoscrollpage"))
 	  {
-	    if (mContinuous)
+	    if (gParams->valueb ("continuous"))
 	      {
 		showpage (mPagenum + 1, (sub - gtk_adjustment_get_page_size(mVaj)) / 2 / sub);
 	      }
@@ -413,10 +414,10 @@ namespace apvlv
   {
     mActive = act;
 
-    if (mActive && filename ())
+    if (mActive && filename () && gView)
       {
 	gchar *base = g_path_get_basename (filename ());
-	mView->settitle (base);
+	gView->settitle (base);
 	g_free (base);
       }
   }
